Learn R Programming

SpatialAcc (version 0.1-5)

GR.Hospitals: Greek Hospitals

Description

Locations of General and Specialised Hospitals in Greece.

Usage

data("GR.Hospitals")

Arguments

Format

A data frame with 132 observations on the following 15 variables.

Address

character vector of hospitals' addresses

Name

a character vector of hospitals' names

ID

a integer vector of hospitals' IDs

X

a numeric vector of x coordinates (GGRS87 - Greek Grid)

Y

a numeric vector of y coordinates (GGRS87 - Greek Grid)

Postcode

a numeric vector of the hospitals' postcodes

URL

a character vector of hospitals' websites

DYPE

a integer vector of hospitals' Healthcare Regions

KallCode

a character vector of municipality codes to link with data from the Hellenic Statistical Authority (EL.STAT.)

Dimos

a character vector of municipality names (Greek with latin characters)

Lat

a numeric vector of hospitals' latitudes (WGS84)

Lon

a numeric vector of hospitals' longitudes (WGS84)

Beds15

a integer vector of hospitals' beds in 2015

Patien15

a integer vector of hospitals' admitted patients (hospital discharges) in 2015

Nights15

a numeric vector of in-patients' nights in 2015

Details

The X,Y coordinates (as well as the Lat/Lon coordinates) refer to the exact locations of operating hospitals in the summer 2016. Their identification is the results of registry data, formal hospital addresses, OpenStreetMap (https://www.openstreetmap.org) and Google Maps (https://maps.google.com) including Street View. They have been manually digitised by the author of this package.

References

Kalogirou, S. (2017). Spatial inequality in the accessibility to hospitals in Greece, The International Archives of the Photogrammetry, Remote Sensing and Spatial Information Sciences, XLII-4/W2, 91-94, https://doi.org/10.5194/isprs-archives-XLII-4-W2-91-2017.

Examples

Run this code
data(GR.Hospitals)
hist(GR.Hospitals$Beds15)

Run the code above in your browser using DataLab